@@ -98,7 +98,7 @@ pub fn get_plan_providers(
     generator.get_plan_providers(&app, &environment)
 }
 
-pub fn create_docker_image(
+pub async fn create_docker_image(
     path: &str,
     envs: Vec<&str>,
     plan_options: &GeneratePlanOptions,
@@ -112,7 +112,9 @@ pub fn create_docker_image(
 
     let logger = Logger::new();
     let builder = DockerImageBuilder::new(logger, build_options.clone());
-    builder.create_image(app.source.to_str().unwrap(), &plan, &environment)?;
+    builder
+        .create_image(app.source.to_str().unwrap(), &plan, &environment)
+        .await?;
 
     Ok(())
 }
