@@ -81,7 +81,7 @@ impl IncrementalCache {
         // #3 Use Docker import: Provide 3 seconds in a sample test
         for f in files {
             let mut docker_import_cmd = Command::new("docker");
-            docker_import_cmd.arg("import").arg(&f?.path()).arg(&tag);
+            docker_import_cmd.arg("import").arg(&f?.path()).arg(tag);
 
             let result = docker_import_cmd
                 .spawn()?
@@ -102,7 +102,7 @@ impl IncrementalCache {
         docker_inspect_cmd
             .arg("manifest")
             .arg("inspect")
-            .arg(&image_tag)
+            .arg(image_tag)
             .stdout(Stdio::null())
             .stderr(Stdio::null());
 
